---
title: <span class="badge builder"></span> BarConfig
---
# <span class="badge builder"></span> BarConfig

## Constructor

```python
BarConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.BarConfig
```

### <span class="badge object-method"></span> bar_alignment

```python
def bar_alignment(bar_alignment: common.BarAlignment) -> typing.Self
```

### <span class="badge object-method"></span> bar_max_width

```python
def bar_max_width(bar_max_width: float) -> typing.Self
```

### <span class="badge object-method"></span> bar_width_factor

```python
def bar_width_factor(bar_width_factor: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [BarConfig](./object-BarConfig.md)
